<?php
/**
 * FSF Member Dashboard
 * Copyright © 2014 Free Software Foundation, Inc.
 *
 * This file is a part of FSF Member Dashboard.
 *
 * FSF Member Dashboard is free software; you can copy, modify, and
 * distribute it under the terms of the GNU Affero General Public
 * License Version 3, 19 November 2007 and the CiviCRM Licensing
 * Exception.
 *
 * FSF Member Dashboard is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FSF Member Dashboard.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

// Safe array reference with default value.
function array_ref($array, $key, $default = NULL) {
  return isset($array[$key]) ? $array[$key] : $default;
}

class CRM_Memberdashboard_BAO_EmailAlias {
  public $id = NULL;
  public $contactId = NULL;
  public $localpart = '';
  public $forward = '';

  static function create($params) {
    $alias = new CRM_Memberdashboard_BAO_EmailAlias($params);
    $alias->save();
    return $alias;
  }

  static function destroy($id) {
    $dao = CRM_Core_DAO::executeQuery(
      'DELETE FROM member_email_alias WHERE id=%1',
      array( 1 => array($id, 'Integer') )
    );

    $dao->free();
  }

  static function find($ids) {
    $dao = CRM_Core_DAO::executeQuery(
      "SELECT * FROM member_email_alias WHERE id IN (" .
      CRM_Core_DAO::escapeString(implode(',', $ids)) . ")"
    );
    $aliases = array();

    while($dao->fetch()) {
      $aliases[$dao->id] = new CRM_Memberdashboard_BAO_EmailAlias(
        array(
          'id' => $dao->id,
          'contact_id' => $dao->contact_id,
          'localpart' => $dao->localpart,
          'forward' => $dao->forward
        )
      );
    }

    $dao->free();

    return $aliases;
  }

  static function findByLocalpart($localpart) {
    $dao = CRM_Core_DAO::executeQuery(
      'SELECT * FROM member_email_alias WHERE localpart=%1',
      array( 1 => array($localpart, 'String') )
    );

    if($dao->fetch()) {
      $alias = new CRM_Memberdashboard_BAO_EmailAlias(
        array(
          'id' => $dao->id,
          'contact_id' => $dao->contact_id,
          'localpart' => $dao->localpart,
          'forward' => $dao->forward
        )
      );
    } else {
      $alias = NULL;
    }

    $dao->free();

    return $alias;
  }

  static function countForContact($contactId) {
    $dao = CRM_Core_DAO::executeQuery(
      'SELECT COUNT(*) AS count FROM member_email_alias WHERE contact_id=%1',
      array( 1 => array($contactId, 'Integer') )
    );

    $dao->fetch();
    $count = $dao->count;
    $dao->free();

    return $count;
  }

  static function allForContact($contactId) {
    $dao = CRM_Core_DAO::executeQuery(
      'SELECT * FROM member_email_alias WHERE contact_id=%1',
      array( 1 => array($contactId, 'Integer') )
    );
    $aliases = array();

    while($dao->fetch()) {
      $aliases[] = new CRM_Memberdashboard_BAO_EmailAlias(
        array(
          'id' => $dao->id,
          'contact_id' => $dao->contact_id,
          'localpart' => $dao->localpart,
          'forward' => $dao->forward
        )
      );
    }

    $dao->free();

    return $aliases;
  }

  function __construct($params) {
    $this->id = array_ref($params, 'id');
    $this->contactId = array_ref($params, 'contact_id');
    $this->localpart = array_ref($params, 'localpart');
    $this->forward = array_ref($params, 'forward');
  }

  function insert() {
    CRM_Core_DAO::executeQuery(
      'INSERT INTO member_email_alias (contact_id, localpart, forward) VALUES (%1, %2, %3)',
      array(1 => array($this->contactId, 'Integer'),
            2 => array($this->localpart, 'String'),
            3 => array($this->forward, 'String'))
    );
  }

  function update() {
    CRM_Core_DAO::executeQuery(
      'UPDATE member_email_alias SET contact_id=%1, localpart=%2, forward=%3 WHERE id=%4',
      array(1 => array($this->contactId, 'Integer'),
            2 => array($this->localpart, 'String'),
            3 => array($this->forward, 'String'),
            4 => array($this->id, 'Integer'))
    );
  }

  function save() {
    if($this->id) {
      $this->update();
    } else {
      $this->insert();
    }
  }
}
