/**
 * @licstart  The following is the entire license notice for the JavaScript code in this page.
 *
 * FSF Member Dashboard
 * Copyright © 2014 Free Software Foundation, Inc.
 *
 * This file is a part of FSF Member Dashboard.
 *
 * FSF Member Dashboard is free software: you can redistribute it
 * and/or modify it under the terms of the GNU Affero General Public
 * License as published by the Free Software Foundation, either
 * version 3 of the License, or (at your option) any later version.
 *
 * FSF Member Dashboard is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FSF Member Dashboard.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * @licend  The above is the entire license notice for the JavaScript code in this page
 */

(function($) {
  // Helper function to support older versions of jQuery that don't
  // parse the JSON returned from AJAX calls by default.
  function parseJSONMaybe(obj) {
    return _.isString(obj) ? JSON.parse(obj): obj;
  }

  function loadProfile(gid, success) {
    $.get('/civicrm/profile/edit', {
      gid: gid,
      json: 1
    }, success);
  }

  function renderProfile(profile) {
    function renderFields() {
      return _.chain(profile)
        .values()
        .filter(function(field) {
          return _.isString(field.label) && _.isString(field.html);
        })
        .map(function (field) {
          return $('<div class="crm-section"></div>')
            .append($('<div class="form-item"></div>')
                    .append($('<div class="label"></div>')
                            .append(field.label))
                    .append($('<div class="content"></div>')
                            .append(field.html))
                    .append($('<div class="clear"></div>')));
        })
        .value();
    }

    profile = parseJSONMaybe(profile);
    var form = $('<form' + profile.attributes + '></form>');

    form.append(profile.requirednote)
      .append(profile.hidden)
      .append.apply(form, renderFields());

    $('#info-loading').remove();
    $('#info-form').append(form);
  }

  // Fetch states/provinces via AJAX.
  function watchForCountryChanges() {
    // TODO: Fetch these ids from the profile JSON.
    var countryId = "#country-Primary, #country-1";
    var stateProvinceId = "#state_province-Primary, #state_province-1";
    var url = "/civicrm/ajax/jqState";

    $(countryId).change(function() {
      $.get(url, {
        _id: $(this).attr('id'),
        _name: $(this).attr('name'),
        _value: $(this).val()
      }, function(states) {
        var stateSelect = $(stateProvinceId);

        function addOption(key, value) {
          stateSelect.get(0).add(new Option(key, value));
        }

        states = parseJSONMaybe(states);
        stateSelect.empty();

        if(_.isEmpty(states)) {
          addOption('- select a country -', '');
        } else {
          _.each(states, function(state) {
            // Civi 4.4 use value, Civi 4.5+ uses key.
            if(state.key) {
              addOption(state.value, state.key);
            } else {
              addOption(state.name, state.value);
            }
          });
        }
      });
    });
  }

  $(document).ready(function() {
    loadProfile(memberDashboard.profileId, function(profile) {
      renderProfile(profile);
      watchForCountryChanges();
    });
  });
})(jQuery);
