<?php

require_once 'memberdashboard.civix.php';

define('MEMBERDASHBOARD_SETTINGS_GROUP', 'Member Dashboard Preferences');
define('MEMBERDASHBOARD_MAX_EMAIL_ALIASES', 5);

/**
 * Implementation of hook_civicrm_config
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_config
 */
function memberdashboard_civicrm_config(&$config) {
  _memberdashboard_civix_civicrm_config($config);
}

/**
 * Implementation of hook_civicrm_xmlMenu
 *
 * @param $files array(string)
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_xmlMenu
 */
function memberdashboard_civicrm_xmlMenu(&$files) {
  _memberdashboard_civix_civicrm_xmlMenu($files);
}

/**
 * Implementation of hook_civicrm_install
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_install
 */
function memberdashboard_civicrm_install() {
  _memberdashboard_civix_civicrm_install();
}

/**
 * Implementation of hook_civicrm_uninstall
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_uninstall
 */
function memberdashboard_civicrm_uninstall() {
  _memberdashboard_civix_civicrm_uninstall();
}

/**
 * Implementation of hook_civicrm_enable
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_enable
 */
function memberdashboard_civicrm_enable() {
  _memberdashboard_civix_civicrm_enable();
}

/**
 * Implementation of hook_civicrm_disable
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_disable
 */
function memberdashboard_civicrm_disable() {
  _memberdashboard_civix_civicrm_disable();
}

/**
 * Implementation of hook_civicrm_upgrade
 *
 * @param $op string, the type of operation being performed; 'check' or 'enqueue'
 * @param $queue CRM_Queue_Queue, (for 'enqueue') the modifiable list of pending up upgrade tasks
 *
 * @return mixed  based on op. for 'check', returns array(boolean) (TRUE if upgrades are pending)
 *                for 'enqueue', returns void
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_upgrade
 */
function memberdashboard_civicrm_upgrade($op, CRM_Queue_Queue $queue = NULL) {
  return _memberdashboard_civix_civicrm_upgrade($op, $queue);
}

/**
 * Implementation of hook_civicrm_managed
 *
 * Generate a list of entities to create/deactivate/delete when this module
 * is installed, disabled, uninstalled.
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_managed
 */
function memberdashboard_civicrm_managed(&$entities) {
  _memberdashboard_civix_civicrm_managed($entities);
}

/**
 * Implementation of hook_civicrm_caseTypes
 *
 * Generate a list of case-types
 *
 * Note: This hook only runs in CiviCRM 4.4+.
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_caseTypes
 */
function memberdashboard_civicrm_caseTypes(&$caseTypes) {
  _memberdashboard_civix_civicrm_caseTypes($caseTypes);
}

/**
 * Implementation of hook_civicrm_alterSettingsFolders
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_alterSettingsFolders
 */
function memberdashboard_civicrm_alterSettingsFolders(&$metaDataFolders = NULL) {
  _memberdashboard_civix_civicrm_alterSettingsFolders($metaDataFolders);
}

/**
 * Implementation of hook_civicrm_post
 *
 * @link http://wiki.civicrm.org/confluence/display/CRMDOC/hook_civicrm_post
 */
function memberdashboard_civicrm_post($op, $objectName, $objectId, &$objectRef) {
  // When a membership is modified, make a RPC to regenerate the
  // member button for the contact.
  $triggerOps = array('create', 'edit', 'delete');

  if($objectName == 'Membership' && in_array($op, $triggerOps)) {
    try {
      // TODO: Extract all of this to a class for clarity and
      // organization's sake.

      // Get the oldest join date for the contact's memberships.
      $contactId = $objectRef->contact_id;
      $dao = CRM_Core_DAO::executeQuery(
        'SELECT join_date FROM civicrm_membership WHERE contact_id=%1 ORDER BY join_date ASC LIMIT 1',
        array( 1 => array($contactId, 'Integer') )
      );

      if($dao->fetch()) {
        // Make the API call.
        $joinDate = $dao->join_date;
        $apiUrl = civicrm_api3('setting', 'getvalue', array(
          'name' => 'memberdashboard_button_api_url',
          'group' => MEMBERDASHBOARD_SETTINGS_GROUP
        ));
        $user = civicrm_api3('setting', 'getvalue', array(
          'name' => 'memberdashboard_button_api_user',
          'group' => MEMBERDASHBOARD_SETTINGS_GROUP
        ));
        $password = civicrm_api3('setting', 'getvalue', array(
          'name' => 'memberdashboard_button_api_password',
          'group' => MEMBERDASHBOARD_SETTINGS_GROUP
        ));

        if(!empty($apiUrl) && !empty($user) && !empty($password)) {
          $url = "$apiUrl?contact_id=" . $contactId . "&date=" . $joinDate;
          $curl = curl_init();
          curl_setopt($curl, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
          curl_setopt($curl, CURLOPT_USERPWD, "$user:$password");
          curl_setopt($curl, CURLOPT_URL, $url);
          curl_exec($curl);
        }
      }

      $dao->free();
    } catch(Exception $e) {
      // Ignore it.  Not the end of the world if this fails.
    }
  }
}

function memberdashboard_civicrm_buildForm($formName, &$form) {
  // Hack to fix state select box in 4.4.x
  if($formName == 'CRM_Profile_Form_Edit') {
    $contactId = CRM_Core_Session::singleton()->get('userID');
    if($concactId) {
      $contact = civicrm_api3('contact', 'getsingle', array( 'id' => $contactId ));
      $defaults['state_province-Primary'] = $contact['state_province_id'];
      $form->setDefaults($defaults);
    }
  }
}
